@@ -28,6 +28,7 @@ __all__ = (
     "GetOutpostOutputTypeDef",
     "ListOutpostsOutputTypeDef",
     "ListSitesOutputTypeDef",
+    "ListTagsForResourceResponseTypeDef",
 )
 
 InstanceTypeItemTypeDef = TypedDict("InstanceTypeItemTypeDef", {"InstanceType": str}, total=False)
@@ -101,3 +102,7 @@ ListSitesOutputTypeDef = TypedDict(
     {"Sites": List["SiteTypeDef"], "NextToken": str, "ResponseMetadata": "ResponseMetadata"},
     total=False,
 )
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef", {"Tags": Dict[str, str]}, total=False
+)
